deriva.transfer.backup package
================================

Submodules
----------

deriva.transfer.backup.deriva\_backup module
------------------------------------------------

.. automodule:: deriva.transfer.backup.deriva_backup
    :members:
    :undoc-members:
    :show-inheritance:

deriva.transfer.backup.deriva\_backup\_cli module
-----------------------------------------------------

.. automodule:: deriva.transfer.backup.deriva_backup_cli
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: deriva.transfer.backup
    :members:
    :undoc-members:
    :show-inheritance:
